@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
+from typing import MutableMapping, MutableSequence
+
 from google.protobuf import field_mask_pb2  # type: ignore
 from google.protobuf import timestamp_pb2  # type: ignore
 import proto  # type: ignore
@@ -90,39 +92,39 @@ class Folder(proto.Message):
         ACTIVE = 1
         DELETE_REQUESTED = 2
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    state = proto.Field(
+    state: State = proto.Field(
         proto.ENUM,
         number=4,
         enum=State,
     )
-    create_time = proto.Field(
+    create_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=5,
         message=timestamp_pb2.Timestamp,
     )
-    update_time = proto.Field(
+    update_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=6,
         message=timestamp_pb2.Timestamp,
     )
-    delete_time = proto.Field(
+    delete_time: timestamp_pb2.Timestamp = proto.Field(
         proto.MESSAGE,
         number=7,
         message=timestamp_pb2.Timestamp,
     )
-    etag = proto.Field(
+    etag: str = proto.Field(
         proto.STRING,
         number=8,
     )
@@ -137,7 +139,7 @@ class GetFolderRequest(proto.Message):
             be of the form ``folders/{folder_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -168,19 +170,19 @@ class ListFoldersRequest(proto.Message):
             state should be returned. Defaults to false.
     """
 
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=2,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=3,
     )
-    show_deleted = proto.Field(
+    show_deleted: bool = proto.Field(
         proto.BOOL,
         number=4,
     )
@@ -190,7 +192,7 @@ class ListFoldersResponse(proto.Message):
     r"""The ListFolders response message.
 
     Attributes:
-        folders (Sequence[google.cloud.resourcemanager_v3.types.Folder]):
+        folders (MutableSequence[google.cloud.resourcemanager_v3.types.Folder]):
             A possibly paginated list of folders that are
             direct descendants of the specified parent
             resource.
@@ -204,12 +206,12 @@ class ListFoldersResponse(proto.Message):
     def raw_page(self):
         return self
 
-    folders = proto.RepeatedField(
+    folders: MutableSequence["Folder"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Folder",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -265,15 +267,15 @@ class SearchFoldersRequest(proto.Message):
                "String".
     """
 
-    page_size = proto.Field(
+    page_size: int = proto.Field(
         proto.INT32,
         number=1,
     )
-    page_token = proto.Field(
+    page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    query = proto.Field(
+    query: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -283,7 +285,7 @@ class SearchFoldersResponse(proto.Message):
     r"""The response message for searching folders.
 
     Attributes:
-        folders (Sequence[google.cloud.resourcemanager_v3.types.Folder]):
+        folders (MutableSequence[google.cloud.resourcemanager_v3.types.Folder]):
             A possibly paginated folder search results.
             the specified parent resource.
         next_page_token (str):
@@ -296,12 +298,12 @@ class SearchFoldersResponse(proto.Message):
     def raw_page(self):
         return self
 
-    folders = proto.RepeatedField(
+    folders: MutableSequence["Folder"] = proto.RepeatedField(
         proto.MESSAGE,
         number=1,
         message="Folder",
     )
-    next_page_token = proto.Field(
+    next_page_token: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -317,7 +319,7 @@ class CreateFolderRequest(proto.Message):
             other fields will be ignored.
     """
 
-    folder = proto.Field(
+    folder: "Folder" = proto.Field(
         proto.MESSAGE,
         number=2,
         message="Folder",
@@ -335,11 +337,11 @@ class CreateFolderMetadata(proto.Message):
             organization we are creating the folder under.
     """
 
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    parent = proto.Field(
+    parent: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -364,12 +366,12 @@ class UpdateFolderRequest(proto.Message):
             can be updated.
     """
 
-    folder = proto.Field(
+    folder: "Folder" = proto.Field(
         proto.MESSAGE,
         number=1,
         message="Folder",
     )
-    update_mask = proto.Field(
+    update_mask: field_mask_pb2.FieldMask = proto.Field(
         proto.MESSAGE,
         number=2,
         message=field_mask_pb2.FieldMask,
@@ -396,11 +398,11 @@ class MoveFolderRequest(proto.Message):
             ``folders/{folder_id}`` or ``organizations/{org_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    destination_parent = proto.Field(
+    destination_parent: str = proto.Field(
         proto.STRING,
         number=2,
     )
@@ -419,15 +421,15 @@ class MoveFolderMetadata(proto.Message):
             organization to move the folder to.
     """
 
-    display_name = proto.Field(
+    display_name: str = proto.Field(
         proto.STRING,
         number=1,
     )
-    source_parent = proto.Field(
+    source_parent: str = proto.Field(
         proto.STRING,
         number=2,
     )
-    destination_parent = proto.Field(
+    destination_parent: str = proto.Field(
         proto.STRING,
         number=3,
     )
@@ -442,7 +444,7 @@ class DeleteFolderRequest(proto.Message):
             Must be of the form ``folders/{folder_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
@@ -464,7 +466,7 @@ class UndeleteFolderRequest(proto.Message):
             be of the form ``folders/{folder_id}``.
     """
 
-    name = proto.Field(
+    name: str = proto.Field(
         proto.STRING,
         number=1,
     )
